<!DOCTYPE html>
<html lang="en">

<head>
  <meta charset="UTF-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <link rel="stylesheet" href="{{ url_for('static',filename='bootstrap/css/bootstrap.min.css')}} ">
  <script src="{{ url_for('static',filename='bootstrap/js/jquery-3.6.1.min.js' ) }}"></script>
  <script src="{{ url_for('static',filename='bootstrap/js/bootstrap.min.js' ) }}"></script>
  {% block fileinput %}
    
  {% endblock %}
  <title style="font-size: large;">{% block title %}
    首页
    {% endblock %}</title>
</head>

<body>

  <div class="container">

    <div class="panel panel-default">
      <div class="panel-heading">
        <h3 class="panel-title text-center">{% block panel_title %}
          文件共享服务器
        {% endblock %} </h3>
      </div>
      <div class="panel-body orm-inline">
        {% block content %}
        <div class="text-center">
          <a href="{{ url_for('upload_file') }}" class="btn btn-info">文件上传</a>
          &nbsp;
          <a href="{{ url_for('download_page') }}" class="btn btn-info">文件下载</a>
        </div>

        {% endblock %}


      </div>
    </div>

  </div>
</body>

</html>